@@ -59,12 +59,11 @@ class StatsNbaApi:
 
         # Read the specification file
         self.specs = json.loads(pkg_resources.read_text('sportsdata.data', 'stats.nba.com.json'))
-        self.logger.info(self.specs)
+        self.logger.info(self.specs.keys())
 
         for endpoint in self.specs['stats_endpoints']:
-            self.add_api_method(self, endpoint)
+            self.add_api_method(endpoint)
 
-    @staticmethod
     def add_api_method(cls, endpoint):
         """
         Dynamically builds a method for each endpoint in the specification file
@@ -74,17 +73,16 @@ class StatsNbaApi:
         :return:
         """
 
-        @classmethod
         def dynamic_method(self, **kwargs):
-
             url = endpoint['url']
             parameters = endpoint['parameters']
             self.logger.info(url)
-            self.logger.info(kwargs)
-            return requests.get(url, params=parameters)
+            # self.logger.info(kwargs)
+            return url, parameters, kwargs
+            #return requests.get(url, params=parameters)
 
         dynamic_method.__name__ = endpoint['name']
-        setattr(cls, dynamic_method.__name__, dynamic_method)
+        setattr(cls, dynamic_method.__name__, classmethod(dynamic_method))
 
     base_url = "https://stats.nba.com/stats/{0}"
     headers = {
